cmoncrawl.aggregator.base
=========================

.. automodule:: cmoncrawl.aggregator.base

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      IAggregator
   
   

   
   
   



